/*
 * Copyright 2012 David B. Lowery
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.aztechengine;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

import org.aztechengine.android.graphics.Graphics;

import android.graphics.Bitmap;
import android.graphics.Canvas;

/**
 * Represents a screen to be displayed and updated while playing a game. Can contain
 * interactive elements.
 * 
 * @author lowery
 *
 */
public abstract class Screen {
    private static Map<String, Bitmap> bitmaps;
    private static Bitmap errBitmap;
    
    public abstract void onLoad();
    public abstract void render(Canvas canvas);
    
    /**
     * Constructor initializes instance variables and loads the default set of system assets
     * (i.e. error images). 
     * 
     */
    public Screen() {
        bitmaps = new HashMap<String, Bitmap>();
        
        try {
            errBitmap = Graphics.getBitmap(Graphics.ERROR_IMG);
        } catch (IOException e) {
            // TODO: log error that system bitmaps aren't being loaded or throw the exception or both..
        }
        
        onLoad();
    }
    
    /** 
     * Preloads the specified image and assigns it an id. Once an image has been loaded it can be
     * referenced by it's id.
     * 
     * @param id the identifier for this image
     * @param filename the filename of the image to load
     */
    public void loadBitmap(String id, String filename) {
        try {
            bitmaps.put(id, Graphics.getBitmap(filename));
        } catch (IOException e) {
            // TODO: add logging info
            bitmaps.put(id, errBitmap);
        }
    }
    
    /**
     * Get the image with the specified id.
     * 
     * @param id the identifier for this image
     * @return a {@link Bitmap} object
     */
    public Bitmap getBitmap(String id) {
        // TODO: what happens if there are duplicate ids.
        return bitmaps.get(id);
    }
}
