/*
 * Copyright 2012 David B. Lowery
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.aztechengine.android.graphics;

import java.io.IOException;
import java.io.InputStream;

import android.content.res.AssetManager;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;

/**
 * @author lowery
 *
 * This class manages game graphics.
 *
 */
public class Graphics {
    public static final String ERROR_IMG = "system/not_found.png";
    private static AssetManager assetManager;
    
    /**
     * The constructor takes an {@link AssetManager} as an argument. This is used when
     * trying to load the resources.
     * 
     */
    public Graphics(AssetManager assetManager) {
        Graphics.assetManager = assetManager;
    }
    
    /**
     * Gets a Bitmap object from the {@link AssetManager}
     * 
     * @param filename the filename of the image to load
     * @return the {@link Bitmap} object
     * @throws IOException
     * 
     */
    public static Bitmap getBitmap(String filename) throws IOException {
        InputStream input = assetManager.open(filename);
        Bitmap bitmap = BitmapFactory.decodeStream(input);
        return bitmap;
    }
}
