/*
 * Copyright 2012 David B. Lowery
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.aztechengine.examples;

import java.io.IOException;

import org.aztechengine.Screen;
import org.aztechengine.State;
import org.aztechengine.android.AndroidGame;
import org.aztechengine.android.graphics.Graphics;
import org.aztechengine.android.touch.TouchEvent;
import org.aztechengine.android.touch.TouchHandler;

import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.os.Bundle;
import android.util.Log;
/**
 * A simple test for {@link AndroidGame}. The main method will initialize and run
 * the game.
 * 
 * @author lowery
 *
 */
public class AztechTest extends AndroidGame {
    public AztechTest() {

    }
    
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        
        setState(new State() {

            public void update() {
                float x1 = 0;
                float y1 = 0;
                float x2 = 0;
                float y2 = 0;

                for (TouchEvent event : TouchHandler.getTouchEvents()) {
                    if (event.pointer == 0) {
                        x1 = event.x;
                        y1 = event.y;
                    } else if (event.pointer == 1) {
                        x2 = event.x;
                        y2 = event.y;
                    }
                }

                Log.d("AztechTest", "Update (x1=" + x1 + ",y1=" + y1 + " x2=" + x2 + ",y2=" + y2);
            }

        });
        setScreen(new Screen() {
            public void render(Canvas canvas) {
                Log.d("AztechTest", "Render (" + AndroidGame.fps + "fps)");
                int width = canvas.getWidth();
                int height = canvas.getHeight();
                
                Paint bgPaint = new Paint();
                bgPaint.setColor(Color.BLUE);
                canvas.drawRect(0, 0, width, height, bgPaint);
                
                canvas.drawBitmap(getBitmap("invalid"), 100, 100, null);
                canvas.drawBitmap(getBitmap("test"), 200, 200, null);
                
            }

            @Override
            public void onLoad() {
                loadBitmap("test", "test.png");
                loadBitmap("invalid", "xyz.png");
            }

        });
    }
}
